import React from "react";
import { Story, Meta } from "@storybook/react/types-6-0";
import { Button, ButtonProps } from "./index";
import colors from "./colors";

export default {
  title: "Button",
  component: Button,
  argTypes: {}
} as Meta;

const Template: Story<ButtonProps> = (args) => <Button {...args} />;

export const Default = Template.bind({});
Default.args = {
  children: "Text Element",
  color: "blue",
  onClick: () => alert("You clicked the button!")
};

export const Green = Template.bind({});
Green.args = {
  children: "Green Button",
  color: "green",
};

export const Secondary = Template.bind({});
Secondary.args = {
  children: "Secondary button",
  color: "blue",
  type: "secondary",
};

export const Tertiary = Template.bind({});
Tertiary.args = {
  children: "Tertiary button",
  color: "blue",
  type: "tertiary"
};

export const Fancy = Template.bind({});
Fancy.args = {
  children: "Fancy Gradient Button (hover me)",
  className: "bg-gradient-to-r from-pink-600 to-red-600 hover:from-blue-600 hover:to-green-600 transition-all duration-700"
};

export const Options = () => (
  <table>
    {Object.keys(colors).map((color) => (
      <tr>
        <td className="p-1">
          <Button color={color} type="primary" className="w-full">
            Primary {color}
          </Button>
        </td>
        <td className="p-1">
          <Button color={color} type="secondary" className="w-full">
            Secondary {color}
          </Button>
        </td>
        <td className="p-1">
          <Button color={color} type="tertiary" className="w-full">
            Tertiary {color}
          </Button>
        </td>
      </tr>
    ))}
  </table>
);
